@@ -89,10 +89,7 @@ from astropy.nddata import InverseVariance
 from astropy.table import Table
 from matplotlib import pyplot as plt      	# visualization libs
 
-try:
-    import pycurl_requests as requests		# faster 'requests' lib
-except ImportError:
-    import requests				# fall-back 'requests' lib
+import pycurl_requests as requests		# faster 'requests' lib
 import pycurl					# low-level interface
 from urllib.parse import quote_plus		# URL encoding
 
@@ -118,8 +115,8 @@ if THIS_HOST[:5] == 'dldev':
     DEF_SERVICE_ROOT = "http://dldev.datalab.noao.edu"
 elif THIS_HOST[:6] == 'dltest':
     DEF_SERVICE_ROOT = "http://dltest.datalab.noao.edu"
-#elif THIS_HOST[:5] == 'munch':                          # DELETE ME
-#    DEF_SERVICE_ROOT = "http://localhost:6998"          # DELETE ME
+elif THIS_HOST[:4] == 'gp12':
+    DEF_SERVICE_ROOT = "http://gp06.datalab.noao.edu:6998"
 
 
 # Allow the service URL for dev/test systems to override the default.
@@ -1330,7 +1327,7 @@ class specClient(object):
         if context in [None, '']:
             context = self.svc_context
         if profile in [None, '']:
-            rofile = self.svc_profile
+            profile = self.svc_profile
 
         # Process optional keyword arguments.
         ofields = kw['fields'] if 'fields' in kw else self.context['id_main']
@@ -1505,11 +1502,11 @@ class specClient(object):
             print('ty ids: ' + str(type(ids)))
 
         # Initialize the payload.
-        data = {'id_list': ids,
+        data = {'id_list': str(ids),
                 'values': values,
                 'format': fmt,
                 'align': align,
-                'cutout': cutout,
+                'cutout': str(cutout),
                 'w0': 0.0,
                 'w1': 0.0,
                 'context': context,
@@ -1535,7 +1532,7 @@ class specClient(object):
             # so we can return a list object.
             _data = []
             for id in ids:
-                data['id_list'] = id
+                data['id_list'] = str(id)
                 resp = requests.post(url, data=data, headers=headers)
                 if fmt.lower() == 'fits':
                     _data.append(resp.content)
@@ -1950,7 +1947,7 @@ class specClient(object):
             ids = id_list
 
         # Initialize the payload.
-        data = {'id_list': list(ids),
+        data = {'id_list': str(list(ids)),
                 'ncols': ny,
                 'context': context,
                 'profile': profile,
@@ -1958,6 +1955,7 @@ class specClient(object):
                 'verbose': verbose
               }
 
+
         resp = requests.post(url, data=data, headers=headers)
         if fmt == 'png':
             return Image.open(BytesIO(resp.content))
@@ -2038,7 +2036,7 @@ class specClient(object):
         url = '%s/stackedImage' % self.svc_url
 
         # Initialize the payload.
-        data = {'id_list': list(id_list),
+        data = {'id_list': str(list(id_list)),
                 'context': context,
                 'xscale': xscale,
                 'yscale': yscale,
